==> formatusb_21.04.04.tar.xz: 64/translations/formatusb_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <location filename="ui_mainwindow.h" line="285"/>
        <source>Program_Name</source>
        <translation>Programos_pavadinimas</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="50"/>
        <location filename="ui_mainwindow.h" line="287"/>
        <source>Quit application</source>
        <translation>Išeiti iš programos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="53"/>
        <location filename="ui_mainwindow.h" line="289"/>
        <source>Close</source>
        <translation>Užverti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="60"/>
        <location filename="ui_mainwindow.h" line="291"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="76"/>
        <location filename="ui_mainwindow.h" line="294"/>
        <source>Display help </source>
        <translation>Rodyti žinyną</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="79"/>
        <location filename="ui_mainwindow.h" line="296"/>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="86"/>
        <location filename="ui_mainwindow.h" line="298"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="102"/>
        <location filename="ui_mainwindow.h" line="300"/>
        <source>Back</source>
        <translation>Atgal</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="160"/>
        <location filename="ui_mainwindow.h" line="302"/>
        <source>Next</source>
        <translation>Tolesnis</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="186"/>
        <location filename="ui_mainwindow.h" line="307"/>
        <source>About this application</source>
        <translation>Apie šią programą</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="189"/>
        <location filename="ui_mainwindow.h" line="309"/>
        <source>About...</source>
        <translation>Apie...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="196"/>
        <location filename="ui_mainwindow.h" line="311"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="237"/>
        <location filename="ui_mainwindow.h" line="321"/>
        <source>USB-DATA</source>
        <translation>USB-DUOMENYS</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="244"/>
        <location filename="ui_mainwindow.h" line="313"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Pasirinkite paskirties USB įrenginį&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="267"/>
        <location filename="ui_mainwindow.h" line="319"/>
        <source>Format</source>
        <translation>Formatuoti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="274"/>
        <location filename="ui_mainwindow.h" line="320"/>
        <source>Refresh drive list</source>
        <translation>Iš naujo įkelti diskų sąrašą</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="288"/>
        <location filename="ui_mainwindow.h" line="322"/>
        <source>File System Label</source>
        <translation>Failų sistemos etiketė</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="318"/>
        <location filename="ui_mainwindow.h" line="314"/>
        <source>fat32</source>
        <translation>fat32</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="323"/>
        <location filename="ui_mainwindow.h" line="315"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="328"/>
        <location filename="ui_mainwindow.h" line="316"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="333"/>
        <location filename="ui_mainwindow.h" line="317"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="354"/>
        <source>Show partitions</source>
        <translation>Rodyti skaidinius</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="361"/>
        <source>Show all devices</source>
        <translation>Rodyti visus įrenginius</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="181"/>
        <source>Success</source>
        <translation>Pavyko</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="181"/>
        <source>Format successful!</source>
        <translation>Formatavimas pavyko!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="183"/>
        <source>Failure</source>
        <translation>Lemtingoji klaida</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="183"/>
        <source>Error encountered in the Format process</source>
        <translation>Formatavimo procese įvyko klaida</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="236"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="236"/>
        <source>Please select a USB device to write to</source>
        <translation>Pasirinkite USB įrenginį į kurį rašyti</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="242"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Šie veiksmai ištrins visus duomenis, esančius 

</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="242"/>
        <source>Do you wish to continue?</source>
        <translation>Ar norite tęsti?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="282"/>
        <source>About %1</source>
        <translation>Apie %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="283"/>
        <source>Version: </source>
        <translation>Versija: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="284"/>
        <source>Program for formatting USB devices</source>
        <translation>Programa, skirta formatuoti USB įrenginius</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="286"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Autorių teisės (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="287"/>
        <source>%1 License</source>
        <translation>%1 licencija</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="295"/>
        <source>%1 Help</source>
        <translation>%1 žinynas</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="about.cpp" line="38"/>
        <source>License</source>
        <translation>Licencija</translation>
    </message>
    <message>
        <location filename="about.cpp" line="39"/>
        <location filename="about.cpp" line="49"/>
        <source>Changelog</source>
        <translation>Keitinių žurnalas</translation>
    </message>
    <message>
        <location filename="about.cpp" line="40"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="about.cpp" line="57"/>
        <source>&amp;Close</source>
        <translation>&amp;Užverti</translation>
    </message>
</context>
</TS>

==> formatusb_22.10.01.tar.xz: 64/translations/formatusb_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Programos_pavadinimas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Show all devices</source>
        <translation>Rodyti visus įrenginius</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Format</source>
        <translation>Formatuoti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="54"/>
        <source>Defaults</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>msdos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>gpt</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Pasirinkite paskirties USB įrenginį&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Show partitions</source>
        <translation>Rodyti skaidinius</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>fat32</source>
        <translation>fat32</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="135"/>
        <source>Refresh drive list</source>
        <translation>Iš naujo įkelti diskų sąrašą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <source>USB-DATA</source>
        <translation>USB-DUOMENYS</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="156"/>
        <source>File System Label</source>
        <translation>Failų sistemos etiketė</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Partition Table Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <source>Quit application</source>
        <translation>Išeiti iš programos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="225"/>
        <source>Close</source>
        <translation>Užverti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>Display help </source>
        <translation>Rodyti žinyną</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>About this application</source>
        <translation>Apie šią programą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>About...</source>
        <translation>Apie...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <source>Next</source>
        <translation>Tolesnis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="380"/>
        <source>Back</source>
        <translation>Atgal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>Success</source>
        <translation>Pavyko</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>Format successful!</source>
        <translation>Formatavimas pavyko!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="180"/>
        <source>Failure</source>
        <translation>Lemtingoji klaida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="180"/>
        <source>Error encountered in the Format process</source>
        <translation>Formatavimo procese įvyko klaida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Please select a USB device to write to</source>
        <translation>Pasirinkite USB įrenginį į kurį rašyti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Šie veiksmai ištrins visus duomenis, esančius 

</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>Do you wish to continue?</source>
        <translation>Ar norite tęsti?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>About %1</source>
        <translation>Apie %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>Version: </source>
        <translation>Versija: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Program for formatting USB devices</source>
        <translation>Programa, skirta formatuoti USB įrenginius</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Autorių teisės (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="257"/>
        <source>%1 License</source>
        <translation>%1 licencija</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>%1 Help</source>
        <translation>%1 žinynas</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>License</source>
        <translation>Licencija</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="35"/>
        <location filename="../about.cpp" line="45"/>
        <source>Changelog</source>
        <translation>Keitinių žurnalas</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="36"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <source>&amp;Close</source>
        <translation>&amp;Užverti</translation>
    </message>
</context>
</TS>
